@@ -1,25 +1,13 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
-from unittest import skip
-
-from servicecatalog_puppet import constants
+from unittest import skip, mock
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class DoExecuteCodeBuildRunTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
-    manifest_file_path = "manifest_file_path"
     code_build_run_name = "code_build_run_name"
-    puppet_account_id = "puppet_account_id"
     region = "region"
     account_id = "account_id"
-    ssm_param_inputs = []
-    launch_parameters = {}
-    manifest_parameters = {}
-    account_parameters = {}
     project_name = "project_name"
-    execution = constants.EXECUTION_MODE_HUB
-    requested_priority = 1
+    manifest_file_path = "manifest_file_path"
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.codebuild_runs import (
@@ -29,18 +17,12 @@ class DoExecuteCodeBuildRunTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
         self.module = do_execute_code_build_run_task
 
         self.sut = self.module.DoExecuteCodeBuildRunTask(
-            manifest_file_path=self.manifest_file_path,
+            **self.get_common_args(),
             code_build_run_name=self.code_build_run_name,
-            puppet_account_id=self.puppet_account_id,
             region=self.region,
             account_id=self.account_id,
-            ssm_param_inputs=self.ssm_param_inputs,
-            launch_parameters=self.launch_parameters,
-            manifest_parameters=self.manifest_parameters,
-            account_parameters=self.account_parameters,
             project_name=self.project_name,
-            requested_priority=self.requested_priority,
-            execution=self.execution,
+            manifest_file_path=self.manifest_file_path,
         )
 
         self.wire_up_mocks()
@@ -63,9 +45,10 @@ class DoExecuteCodeBuildRunTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
 
     def test_api_calls_used(self):
         # setup
+        self.sut.get_account_used = mock.MagicMock(name="get_account_used")
         expected_result = [
-            f"codebuild.start_build_{self.puppet_account_id}_{self.project_name}",
-            f"codebuild.batch_get_projects_{self.puppet_account_id}_{self.project_name}",
+            f"codebuild.start_build_{self.sut.get_account_used()}_{self.project_name}",
+            f"codebuild.batch_get_projects_{self.sut.get_account_used()}_{self.project_name}",
         ]
 
         # exercise
