@@ -1,28 +1,20 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class TerminateProductDryRunTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
-    manifest_file_path = "manifest_file_path"
     launch_name = "launch_name"
-    portfolio = "portfolio"
-    portfolio_id = "portfolio_id"
-    product = "product"
-    product_id = "product_id"
-    version = "version"
-    version_id = "version_id"
-    account_id = "account_id"
     region = "region"
-    puppet_account_id = "puppet_account_id"
-    retry_count = 1
-    ssm_param_outputs = []
-    worker_timeout = 3
-    parameters = {}
+    account_id = "account_id"
+    portfolio = "portfolio"
+    product = "product"
+    version = "version"
     ssm_param_inputs = []
+    launch_parameters = {}
+    manifest_parameters = {}
+    account_parameters = {}
+    ssm_param_outputs = []
+    execution = "execution"
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.launch import terminate_product_dry_run_task
@@ -30,42 +22,23 @@ class TerminateProductDryRunTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest)
         self.module = terminate_product_dry_run_task
 
         self.sut = self.module.TerminateProductDryRunTask(
-            manifest_file_path=self.manifest_file_path,
+            **self.get_common_args(),
             launch_name=self.launch_name,
-            portfolio=self.portfolio,
-            portfolio_id=self.portfolio_id,
-            product=self.product,
-            product_id=self.product_id,
-            version=self.version,
-            version_id=self.version_id,
-            account_id=self.account_id,
             region=self.region,
-            puppet_account_id=self.puppet_account_id,
-            retry_count=self.retry_count,
-            ssm_param_outputs=self.ssm_param_outputs,
-            worker_timeout=self.worker_timeout,
-            parameters=self.parameters,
+            account_id=self.account_id,
+            portfolio=self.portfolio,
+            product=self.product,
+            version=self.version,
             ssm_param_inputs=self.ssm_param_inputs,
+            launch_parameters=self.launch_parameters,
+            manifest_parameters=self.manifest_parameters,
+            account_parameters=self.account_parameters,
+            ssm_param_outputs=self.ssm_param_outputs,
+            execution=self.execution,
         )
 
         self.wire_up_mocks()
 
-    def test_params_for_results_display(self):
-        # setup
-        expected_result = {
-            "puppet_account_id": self.puppet_account_id,
-            "launch_name": self.launch_name,
-            "account_id": self.account_id,
-            "region": self.region,
-            "cache_invalidator": self.cache_invalidator,
-        }
-
-        # exercise
-        actual_result = self.sut.params_for_results_display()
-
-        # verify
-        self.assertDictEqual(expected_result, actual_result)
-
     def test_api_calls_used(self):
         # setup
         expected_result = [
