@@ -1,19 +1,14 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
-class ShareAndAcceptPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
-    manifest_file_path = "manifest_file_path"
+class ShareAndAcceptPortfolioForAccountTaskTest(
+    tasks_unit_tests_helper.PuppetTaskUnitTest
+):
     account_id = "account_id"
     region = "region"
     portfolio = "portfolio"
-    puppet_account_id = "puppet_account_id"
-    sharing_mode = "sharing_mode"
-    cache_invalidator = "cache_invalidator"
+    portfolio_task_reference = "portfolio_task_reference"
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.portfolio.sharing_management import (
@@ -22,13 +17,12 @@ class ShareAndAcceptPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest
 
         self.module = share_and_accept_portfolio_task
 
-        self.sut = self.module.ShareAndAcceptPortfolioTask(
-            manifest_file_path=self.manifest_file_path,
+        self.sut = self.module.ShareAndAcceptPortfolioForAccountTask(
+            **self.get_common_args(),
             account_id=self.account_id,
             region=self.region,
             portfolio=self.portfolio,
-            puppet_account_id=self.puppet_account_id,
-            sharing_mode=self.sharing_mode,
+            portfolio_task_reference=self.portfolio_task_reference,
         )
 
         self.wire_up_mocks()
@@ -36,11 +30,11 @@ class ShareAndAcceptPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest
     def test_params_for_results_display(self):
         # setup
         expected_result = {
+            "task_reference": self.task_reference,
             "puppet_account_id": self.puppet_account_id,
             "portfolio": self.portfolio,
             "region": self.region,
             "account_id": self.account_id,
-            "sharing_mode": self.sharing_mode,
         }
 
         # exercise
@@ -52,10 +46,10 @@ class ShareAndAcceptPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest
     def test_api_calls_used(self):
         # setup
         expected_result = [
-            f"servicecatalog.list_accepted_portfolio_shares_single_page{self.account_id}_{self.region}",
-            f"servicecatalog.accept_portfolio_share{self.account_id}_{self.region}",
-            f"servicecatalog.associate_principal_with_portfolio{self.account_id}_{self.region}",
-            f"servicecatalog.list_principals_for_portfolio{self.account_id}_{self.region}",
+            f"servicecatalog.list_accepted_portfolio_shares_{self.account_id}_{self.region}",
+            f"servicecatalog.list_portfolio_access_{self.account_id}_{self.region}",
+            f"servicecatalog.create_portfolio_share_{self.account_id}_{self.region}",
+            f"servicecatalog.accept_portfolio_share_{self.account_id}_{self.region}",
         ]
 
         # exercise
