@@ -1,25 +1,16 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class DoExecuteTagPoliciesTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
-    manifest_file_path = "manifest_file_path"
-
     tag_policy_name = "tag_policy_name"
-    puppet_account_id = "puppet_account_id"
-
     region = "region"
     account_id = "account_id"
     ou_name = "ou_name"
-
     content = {}
     description = "description"
-
-    requested_priority = 9
+    manifest_file_path = "manifest_file_path"
+    requested_priority = 1
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.tag_policies import (
@@ -29,15 +20,15 @@ class DoExecuteTagPoliciesTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
         self.module = do_execute_tag_policies_task
 
         self.sut = self.module.DoExecuteTagPoliciesTask(
-            manifest_file_path=self.manifest_file_path,
+            **self.get_common_args(),
             tag_policy_name=self.tag_policy_name,
-            puppet_account_id=self.puppet_account_id,
             region=self.region,
             account_id=self.account_id,
-            requested_priority=self.requested_priority,
             ou_name=self.ou_name,
             content=self.content,
             description=self.description,
+            manifest_file_path=self.manifest_file_path,
+            requested_priority=self.requested_priority,
         )
 
         self.wire_up_mocks()
@@ -59,6 +50,15 @@ class DoExecuteTagPoliciesTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
         # verify
         self.assertEqual(expected_result, actual_result)
 
+    @skip
+    def test_requires(self):
+        # setup
+        # exercise
+        actual_result = self.sut.requires()
+
+        # verify
+        raise NotImplementedError()
+
     def test_api_calls_used(self):
         # setup
         expected_result = [
